/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package com.nativobject.directory.portlet;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


import java.util.List;
import javax.faces.application.FacesMessage;
import javax.faces.context.FacesContext;
import javax.inject.Inject;
import javax.inject.Named;
import org.richfaces.component.UITree;
import org.richfaces.model.TreeNode;
import org.richfaces.model.TreeNodeImpl;
import org.springframework.context.annotation.Scope;

import com.nativobject.directory.dao.DepartmentDao;
import com.nativobject.directory.data.Department;
import com.nativobject.directory.data.Person;

/**
 *
 * @author mourad
 */
@Named("departmentSearchBean")
@Scope("request")
public class DepartmentSearchBean {

      private Logger logger = LoggerFactory.getLogger(getClass());
      @Inject
      private DepartmentDao departmentDao;
      private List<Department> searchResultList;
      private Department selectedDepartment;
      private String searchRequest;

      public String getSearchRequest() {
            return searchRequest;
      }

      public void setSearchRequest(String searchRequest) {
            this.searchRequest = searchRequest;
      }

      public List<Department> getSearchResultList() {
            logger.trace("getSearchResultList {}", searchResultList);
            return searchResultList;
      }

      public int getCurrentResultCount() {
            int count = 0;
            if (searchResultList != null) {
                  count = searchResultList.size();
            }
            return count;
      }

      public TreeNode getDepartmentNodes() {
            TreeNode rootNode = new TreeNodeImpl();
            rootNode.setData("root");
            rootNode.setParent(null);

            if (searchResultList != null) {
                  populateDepartments(rootNode, searchResultList);
            }
            return rootNode;
      }

      private void populateDepartments(TreeNode parentNode, List<Department> departments) {
            for (Department department : departments) {
                  TreeNode departmentNode = new TreeNodeImpl();
                  departmentNode.setData(department);
                  parentNode.addChild(department.getName().hashCode(), departmentNode);
                  populatePersons(departmentNode, department.getPersons());
            }
      }

      private void populatePersons(TreeNode parentNode, List<Person> persons) {
            for (Person person : persons) {
                  TreeNode personNode = new TreeNodeImpl();
                  personNode.setData(person);
                  parentNode.addChild(person.getName().hashCode(), personNode);
            }
      }

      public boolean adviseOpened(UITree tree) {
            return true;
      }

      public List<Department> userSuggestion(Object suggest) {
            logger.trace("Searching for suggestions...");
            return departmentDao.findStartBy((String) suggest);
      }

      public Department getSelectedDepartment() {
            return selectedDepartment;
      }

      public void setSelectedDepartment(Department department) {
            this.selectedDepartment = department;
      }

      public String[] getDepartementNames() {
            List<Department> departments = departmentDao.findAll();
            String[] departmentNames = new String[departments.size()];

            for (int i = 0; i < departments.size(); i++) {
                  departmentNames[i] = departments.get(i).getName();
            }
            return departmentNames;
      }

      public String performSearch() {
            searchResultList = departmentDao.findStartBy(searchRequest);
            String outcome = null;
            if (searchResultList.size() == 1) {
                  selectedDepartment = searchResultList.get(0);
                  outcome = "goToShowDepartment";
            } else if (searchResultList.isEmpty()) {
                  FacesContext.getCurrentInstance().addMessage(null, new FacesMessage("Pas de resultat pour \"" + searchRequest + "\""));
                  outcome = "";
            } else {
                  outcome = "goToDepartmentResult";
            }
            return outcome;
      }

      /**
       *
       * @return l'id du panel à rafraichir
       */
      public void refreshedResult() {
            logger.trace("refreshedResult");
            searchResultList = departmentDao.findStartBy(searchRequest);
            if (searchResultList.isEmpty()) {
                  FacesContext.getCurrentInstance().addMessage(null, new FacesMessage("Pas de resultat pour \"" + searchRequest + "\""));
            }
      }
}
