package com.nativobject.directory.portlet;

import org.slf4j.Logger;
import java.util.List;

import javax.faces.application.FacesMessage;
import javax.faces.context.FacesContext;
import javax.inject.Inject;
import javax.inject.Named;
import org.richfaces.model.TreeNode;
import org.richfaces.model.TreeNodeImpl;
import org.springframework.context.annotation.Scope;

import com.nativobject.directory.dao.PersonDao;
import com.nativobject.directory.data.Person;
import org.slf4j.LoggerFactory;

@Named("userSearchBean")
@Scope("request")
public class UserSearchBean {

	private Logger logger = LoggerFactory.getLogger(getClass());
	@Inject
	private PersonDao personDao;
	private List<Person> searchList;
	private Person selectedPerson;
	private String searchRequest;

	public String getSearchRequest() {
		return searchRequest;
	}

	public void setSearchRequest(String searchRequest) {
		this.searchRequest = searchRequest;
	}

	public List<Person> getByNamePattern() {
		logger.debug("getByNamePattern");
		return searchList;
	}

	public int getCurrentResultCount() {
		int count = 0;
		if (searchList != null) {
			count = searchList.size();
		}
		return count;
	}

	public List<Person> userSuggestion(Object suggest) {

		logger.debug("Recherche de suggestions...");
		if (logger.isTraceEnabled()) {
			for (Person person : personDao.getByfullName((String) suggest)) {
				logger.trace("person uid : {}", person.getUid());
			}
		}
		return personDao.getByfullName((String) suggest);
	}

	public Person getSelectedPerson() {
		return selectedPerson;
	}

	public void setSelectedPerson(Person selectedPerson) {
		this.selectedPerson = selectedPerson;
	}

	public String performSearch() {
		logger.debug("Recherche ");
		searchList = personDao.getByfullName(searchRequest);
		if (searchList.size() == 1) {
			selectedPerson = searchList.get(0);
			return "goToShowPerson";
		}
		if (searchList.isEmpty()) {

			return "";
		}
		return "goToResult";

	}

	public TreeNode<Person> getPersonNodes() {

		TreeNode<Person> rootNode = null;
		if (searchList != null) {
			logger.debug("génération des noeuds...");
			rootNode = new TreeNodeImpl<Person>();
			for (Person person : searchList) {
				TreeNode<Person> personNode = new TreeNodeImpl<Person>();
				personNode.setParent(rootNode);
				personNode.setData(person);
			}
		}
		return rootNode;
	}

	public void searchResult() {
		logger.debug("Recherche ");
		searchList = personDao.getByfullName(searchRequest);
		if (searchList.isEmpty()) {
			FacesContext.getCurrentInstance().addMessage(null,
					new FacesMessage("Pas de resultat pour \"" + searchRequest + "\""));
		}
	}
}
